/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifndef _AMT_STATUS_THREAD_H
#define _AMT_STATUS_THREAD_H
#include "PeriodicActionThread.h"
#include "IPCAMTStatus.h"
#include "UNSConfig.h"

class UNSConfig;
class UNSEventLogger;

class AMTStatusThread : public PeriodicActionThread
{
public:
	// Constructor
	AMTStatusThread(UNSEventLogger *pLogger = NULL);
	virtual ~AMTStatusThread();

	// Initialize this thread with a given action interval time.
	bool init(const UNSConfig &UNSConfig);

	// Set a pointer to the Logger.
	void SetLogger(UNSEventLogger *pLogger) {m_pLogger = pLogger;}

protected:
	// The periodic action
	virtual void action();

	// cleanup function - called when action is stopped
	virtual void cleanup();

private:
	static const unsigned long DEFAULT_CHECK_AMT_STATUS_TIMEOUT;
	static const unsigned long HECI_DOWNTIME_ON_RESUME;
	enum State {INITIAL_STATE, ENABLED_STATE, POSSIBLY_DISABLED_STATE, DISABLED_STATE};

	void debugLog(const char *msg);
	bool IsAMTEnabledByHECI(bool bLogging = false);
	State SetAMTEnabled(bool bEnabled, bool bLogging = false);

	State OnInitialState();
	State OnEnabledState();
	State OnPossiblyDisabledState(bool bNeedCheck = true);
	State OnDisabledState();

	State m_State;
	unsigned long m_nNumPollsDisabled;
	UNSConfig m_UNSConfig;
	UNSEventLogger *m_pLogger;
	IPCAMTStatus m_AMTStatus;
};

#endif //_AMT_STATUS_THREAD_H
