/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

//----------------------------------------------------------------------------
//
//  File:       BaseEventLog.h
//
//  Notes:      Definistion of Abstract Class BaseEventLog used to set an Event to the log
//
//----------------------------------------------------------------------------

#ifndef _BASE_LOG_H
#define _BASE_LOG_H

#include <stdlib.h>

#define ERROR_EVENT 0
#define DEBUG_EVENT 1
#define WARNING_EVENT 2


class BaseEventLog
{

public:
	//*********************************************
	//BaseEventLog:
	//Ctor to BaseEventLog object
	//*********************************************
	BaseEventLog(){}

	//*********************************************
	//~BaseEventLog:
	//Dtor to BaseEventLog object
	//*********************************************
	virtual ~BaseEventLog(){};

	//*********************************************
	//LogEvent:
	//Record Events for debugging.
	//params:
	//@categoryID - category ID
	//@eventID    - event ID
	//*********************************************
	virtual void LogEvent(unsigned short CategoryID, unsigned long EventID, unsigned long	EventType) = 0;

	//*********************************************
	//LogEvent:
	//Record Events for debugging.
	//params:
	//@categoryID - category ID
	//@eventID    - event ID
	//@EventType
	//@ArrayOfStrings
	//@NumOfArrayStr
	//@RawData
	//@RawDataSize
	//*********************************************
	virtual void LogEvent(unsigned short CategoryID,unsigned long	EventID
		          , unsigned long	EventType,const char * ArrayOfStrings[],
				  unsigned int NumOfArrayStr, void * RawData=NULL, unsigned long RawDataSize=0)=0;
};

#endif //_BASE_LOG_H
