/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifndef  _EAC_WSMAN_CLIENT_H
#define  _EAC_WSMAN_CLIENT_H

#include "AMT_EndpointAccessControlService.h"
#include "BaseWSManClient.h"
#include "UNSStatus.h"
#include <string>

using namespace CimClassNamespace;

class EACWSManClient : public BaseWSManClient
{
public:
	EACWSManClient();
	virtual ~EACWSManClient();

	/*Actual soap actions!*/

	/*Note: The pointers set in ppPosture and ppChangeHash are only valid as long as
	  the EACSoapClient object lives.*/
	bool GetPosture(unsigned char **ppPosture, unsigned int &nPostureLen,
                     unsigned char **ppChangeHash, unsigned int &nChangeHashLen);

	/*Note: The pointer set in ppHash is only valid as long as
	the EACSoapClient object lives.*/
	bool GetPostureHash(unsigned char **ppHash, unsigned int &nHashLen);

	bool IsEACEnabled(bool &bEACEnabled);

	bool Init(bool forceGet = false);
private:
	bool SaveData(int nNewLength, int &nOldLength, unsigned char **ppDest, unsigned char *pSource);

	unsigned char *m_pPosture;
	unsigned char *m_pChangeHash;
	unsigned char *m_pHash;

	int m_nPostureLen;
	int m_nChangeHashLen;
	int m_nHashLen;
	bool m_isInit;
	static const std::string DEFAULT_USER;
	static const std::string DEFAULT_PASS;
	AMT_EndpointAccessControlService m_service;
};

#endif //_EAC_SOAP_CLIENT_H
