/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

//////////////////////////////////////////////////////////////////////////
// Lock.h
//
// This file contains the definition and implementation of the Lock class
// and the TryLock class
//////////////////////////////////////////////////////////////////////////
#ifndef _LAD_LOCK_H
#define _LAD_LOCK_H
#include "RWLock.h"

#ifndef NULL
#define NULL 0
#endif

class Lock {
public:
    Lock(Semaphore &sem) : _sem(&sem), _rw_lock(NULL)
	{
		_sem->acquire();
	}

    Lock(RWLock &rw_lock, RWLock::RWMode mode = RWLock::READ_ONLY) :
	_sem(NULL), _rw_lock(&rw_lock)
	{
		_rw_lock->acquire(mode);
	}
    ~Lock()
	{
	    if (_sem) {
            _sem->release();
	    }
	    if (_rw_lock) {
			_rw_lock->release();
	    }

	}
private:
    Semaphore *_sem;
    RWLock *_rw_lock;
};

class TryLock {
public:
    TryLock(Semaphore &sem, bool &is_locked) : _sem(&sem)
	{
		_locked = _sem->acquireTry();
		is_locked = _locked;
	}
    ~TryLock()
	{
		if (_locked) {
			_sem->release();
		}
	}
private:
    bool _locked;
    Semaphore *_sem;
};

#endif //_LAD_LOCK_H

