/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include "RWLock.h"

RWLock::RWLock() : _counter(0) {}

void RWLock::acquire(const RWMode mode_p)
{

    if (mode_p == READ_ONLY) {
        //wait for writer's exit
        _writeSem.acquire();
        //might be blocked only to decrement _counter and _readSem.release() in release()
        _countSem.acquire();
        int tmp = ++_counter;
        _countSem.release();
        if (tmp == 1) {
            //never blocks, no writers, first reader
            _readSem.acquire();
		}
        _writeSem.release();
	} else {
        _writeSem.acquire();
        //wait for reader's exit
        _readSem.acquire();
    }

    return;
}

//will do nothing if no read-write lock was acquired
void RWLock::switch2RO()
{
    _countSem.acquire();
    if (!_counter) {
       _counter = 1;
       _writeSem.release();
	}
    _countSem.release();
}

//will do nothing if no lock was acquired
void RWLock::release()
{

    //might be blocked only to increment _counter in read-only mode
    _countSem.acquire();
	if (_counter) {
        //read-only mode
        _counter--;
        if (!_counter) {
            //the last reader
            _readSem.release();
		}
	} else {
        //read-write mode
        _readSem.release();
        _writeSem.release();
    }
    _countSem.release();

    return;
}





