/*******************************************************************************
 * Part of "Intel(R) Active Management Technology (Intel(R) AMT)
 *                   User Notification Service (UNS)"
 *
 * Copyright (c) 2007 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *******************************************************************************/

#include "AMT_EndpointAccessControlService.h"
using namespace CimClassNamespace;

AMT_EndpointAccessControlService::RequestStateChange_INPUT::RequestStateChange_INPUT()
	:Serializable("RequestStateChange_INPUT", AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX),
	RequestedStateSpecified(false),
	TimeoutPeriodSpecified(false){}

void AMT_EndpointAccessControlService::RequestStateChange_INPUT::SerializeMembers(XMLElement& node) const
{
	if(RequestedStateSpecified)
	{
		node.AppendLeaf("RequestedState", RequestedState, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	}
	if(TimeoutPeriodSpecified)
	{
		node.AppendLeaf("TimeoutPeriod", TimeoutPeriod, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	}
}

AMT_EndpointAccessControlService::RequestStateChange_OUTPUT::RequestStateChange_OUTPUT()
	:DeSerializable("RequestStateChange_OUTPUT",AMT_EndpointAccessControlService::CLASS_URI),
	JobSpecified(false){}

void AMT_EndpointAccessControlService::RequestStateChange_OUTPUT::SetValue(const XMLElement& node)
{
	string name = node.GetNodeName();
	if(name == "Job")
	{
		node.SetComplexType(Job);
		JobSpecified = true;
	}
	else if(name == "ReturnValue")
	{
		node.SetValue(ReturnValue);
	}
}

AMT_EndpointAccessControlService::GetPosture_INPUT::GetPosture_INPUT()
	:Serializable("GetPosture_INPUT", AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX){}

void AMT_EndpointAccessControlService::GetPosture_INPUT::SerializeMembers(XMLElement& node) const
{
	node.AppendLeaf("PostureType", PostureType, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
}

AMT_EndpointAccessControlService::GetPosture_OUTPUT::GetPosture_OUTPUT()
	:DeSerializable("GetPosture_OUTPUT",AMT_EndpointAccessControlService::CLASS_URI),
	SignedPostureSpecified(false),
	PostureChangeHashSpecified(false){}

void AMT_EndpointAccessControlService::GetPosture_OUTPUT::SetValue(const XMLElement& node)
{
	string name = node.GetNodeName();
	if(name == "SignedPosture")
	{
		node.SetValue(SignedPosture);
		SignedPostureSpecified = true;
	}
	else if(name == "PostureChangeHash")
	{
		node.SetValue(PostureChangeHash);
		PostureChangeHashSpecified = true;
	}
	else if(name == "ReturnValue")
	{
		node.SetValue(ReturnValue);
	}
}

AMT_EndpointAccessControlService::GetPostureHash_INPUT::GetPostureHash_INPUT()
	:Serializable("GetPostureHash_INPUT", AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX){}

void AMT_EndpointAccessControlService::GetPostureHash_INPUT::SerializeMembers(XMLElement& node) const
{
	node.AppendLeaf("PostureType", PostureType, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
}

AMT_EndpointAccessControlService::GetPostureHash_OUTPUT::GetPostureHash_OUTPUT()
	:DeSerializable("GetPostureHash_OUTPUT",AMT_EndpointAccessControlService::CLASS_URI),
	PostureChangeHashSpecified(false){}

void AMT_EndpointAccessControlService::GetPostureHash_OUTPUT::SetValue(const XMLElement& node)
{
	string name = node.GetNodeName();
	if(name == "PostureChangeHash")
	{
		node.SetValue(PostureChangeHash);
		PostureChangeHashSpecified = true;
	}
	else if(name == "ReturnValue")
	{
		node.SetValue(ReturnValue);
	}
}

AMT_EndpointAccessControlService::UpdatePostureState_INPUT::UpdatePostureState_INPUT()
	:Serializable("UpdatePostureState_INPUT", AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX){}

void AMT_EndpointAccessControlService::UpdatePostureState_INPUT::SerializeMembers(XMLElement& node) const
{
	node.AppendLeaf("UpdateType", UpdateType, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
}

AMT_EndpointAccessControlService::UpdatePostureState_OUTPUT::UpdatePostureState_OUTPUT()
	:DeSerializable("UpdatePostureState_OUTPUT",AMT_EndpointAccessControlService::CLASS_URI){}

void AMT_EndpointAccessControlService::UpdatePostureState_OUTPUT::SetValue(const XMLElement& node)
{
	string name = node.GetNodeName();
	if(name == "ReturnValue")
	{
		node.SetValue(ReturnValue);
	}
}

AMT_EndpointAccessControlService::AMT_EndpointAccessControlService(
		const string& objName,
		const string& uri,
		const string& ns,
		const string& nsPrefix)
		:CIM_Service(objName, uri, ns, nsPrefix){}

void  AMT_EndpointAccessControlService::SerializeMembers(XMLElement& node) const
{
	node.AppendLeaf("CreationClassName", CreationClassName, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	if(ElementNameSpecified)
	{
		node.AppendLeaf("ElementName", ElementName, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	}
	if(EnabledStateSpecified)
	{
		node.AppendLeaf("EnabledState", EnabledState, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	}
	node.AppendLeaf("Name", Name, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	if(RequestedStateSpecified)
	{
		node.AppendLeaf("RequestedState", RequestedState, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	}
	node.AppendLeaf("SystemCreationClassName", SystemCreationClassName, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
	node.AppendLeaf("SystemName", SystemName, AMT_EndpointAccessControlService::CLASS_URI, AMT_EndpointAccessControlService::CLASS_NS_PREFIX);
}

NameValuePairs AMT_EndpointAccessControlService::GetSelectorsList() const
{
	NameValuePairs serList;
	serList["CreationClassName"] = XMLTypeConverter::TypeToString(CreationClassName);
	serList["Name"] = XMLTypeConverter::TypeToString(Name);
	serList["SystemCreationClassName"] = XMLTypeConverter::TypeToString(SystemCreationClassName);
	serList["SystemName"] = XMLTypeConverter::TypeToString(SystemName);
	return serList;
}

void AMT_EndpointAccessControlService::SetValue(const XMLElement& node)
{
	string name = node.GetNodeName();
	if(name == "Started")
	{
		node.SetValue(Started);
		StartedSpecified = true;
	}
	else if(name == "StartMode")
	{
		node.SetValue(StartMode);
		StartModeSpecified = true;
	}
	else if(name == "PrimaryOwnerContact")
	{
		node.SetValue(PrimaryOwnerContact);
		PrimaryOwnerContactSpecified = true;
	}
	else if(name == "PrimaryOwnerName")
	{
		node.SetValue(PrimaryOwnerName);
		PrimaryOwnerNameSpecified = true;
	}
	else if(name == "Name")
	{
		node.SetValue(Name);
	}
	else if(name == "CreationClassName")
	{
		node.SetValue(CreationClassName);
	}
	else if(name == "SystemName")
	{
		node.SetValue(SystemName);
	}
	else if(name == "SystemCreationClassName")
	{
		node.SetValue(SystemCreationClassName);
	}
	else if(name == "ElementName")
	{
		node.SetValue(ElementName);
		ElementNameSpecified = true;
	}
	else if(name == "Description")
	{
		node.SetValue(Description);
		DescriptionSpecified = true;
	}
	else if(name == "Caption")
	{
		node.SetValue(Caption);
		CaptionSpecified = true;
	}
	else if(name == "InstallDate")
	{
		node.SetValue(InstallDate);
		InstallDateSpecified = true;
	}
	else if(name == "OperationalStatus")
	{
		node.AddValue(OperationalStatus);
	}
	else if(name == "StatusDescriptions")
	{
		node.AddValue(StatusDescriptions);
	}
	else if(name == "Status")
	{
		node.SetValue(Status);
		StatusSpecified = true;
	}
	else if(name == "HealthState")
	{
		node.SetValue(HealthState);
		HealthStateSpecified = true;
	}
	else if(name == "EnabledState")
	{
		node.SetValue(EnabledState);
		EnabledStateSpecified = true;
	}
	else if(name == "OtherEnabledState")
	{
		node.SetValue(OtherEnabledState);
		OtherEnabledStateSpecified = true;
	}
	else if(name == "RequestedState")
	{
		node.SetValue(RequestedState);
		RequestedStateSpecified = true;
	}
	else if(name == "EnabledDefault")
	{
		node.SetValue(EnabledDefault);
		EnabledDefaultSpecified = true;
	}
	else if(name == "TimeOfLastStateChange")
	{
		node.SetValue(TimeOfLastStateChange);
		TimeOfLastStateChangeSpecified = true;
	}
}

void AMT_EndpointAccessControlService::InvokeRequestStateChange(RequestStateChange_INPUT &input, RequestStateChange_OUTPUT &output, const WsmanClient *cl) const
{
	Invoke("RequestStateChange", &input, &output, cl);
}
void AMT_EndpointAccessControlService::InvokeGetPosture(GetPosture_INPUT &input, GetPosture_OUTPUT &output, const WsmanClient *cl) const
{
	Invoke("GetPosture", &input, &output, cl);
}
void AMT_EndpointAccessControlService::InvokeGetPostureHash(GetPostureHash_INPUT &input, GetPostureHash_OUTPUT &output, const WsmanClient *cl) const
{
	Invoke("GetPostureHash", &input, &output, cl);
}
void AMT_EndpointAccessControlService::InvokeUpdatePostureState(UpdatePostureState_INPUT &input, UpdatePostureState_OUTPUT &output, const WsmanClient *cl) const
{
	Invoke("UpdatePostureState", &input, &output, cl);
}
const string AMT_EndpointAccessControlService::CLASS_NAME = "AMT_EndpointAccessControlService";
const string AMT_EndpointAccessControlService::CLASS_URI = "http://intel.com/wbem/wscim/1/amt-schema/1/AMT_EndpointAccessControlService";
const string AMT_EndpointAccessControlService::CLASS_NS = "http://intel.com/wbem/wscim/1/amt-schema/1/AMT_EndpointAccessControlService";
const string AMT_EndpointAccessControlService::CLASS_NS_PREFIX = "vxEncd";
